@@ -1,5 +1,5 @@
 /*
- * demo for changing between different calibrations
+ * demo for changing between different (hardware-based) calibrations
  * Part of Comedilib
  *
  * Copyright (c) 1999,2000 David A. Schleef <ds@schleef.org>
@@ -29,24 +29,26 @@ int main(int argc, char *argv[])
 {
 	lsampl_t data;
 	int ret;
+	struct parsed_options options;
 
-	parse_options(argc,argv);
+	init_parsed_options(&options);
+	parse_options(&options, argc, argv);
 
-	device=comedi_open(filename);
+	device=comedi_open(options.filename);
 	if(!device){
-		comedi_perror(filename);
-		exit(0);
+		comedi_perror(options.filename);
+		exit(-1);
 	}
 
-	data = value; 
-	if(verbose){
+	data = options.value;
+	if(options.verbose){
 		printf("writing %d to device=%s subdevice=%d channel=%d range=%d analog reference=%d\n",
-			data,filename,subdevice,channel,range,aref);
+			data, options.filename, options.subdevice, options.channel, options.range, options.aref);
 	}
 
-	ret=comedi_apply_calibration(device,subdevice,channel,range,aref,NULL);
-	if(ret<0){
-		comedi_perror(filename);
+	ret = comedi_apply_calibration(device, options.subdevice, options.channel, options.range, options.aref, NULL);
+	if(ret < 0){
+		comedi_perror(options.filename);
 		exit(0);
 	}
 
