@@ -47,18 +47,8 @@ int main(int argc, char *argv[])
 	}
 	filter_selection = options.value;
 	printf("Selecting filter %d on subdevice %d channel %d.\n", filter_selection, options.subdevice, options.channel);
-	comedi_insn insn;
-	lsampl_t data[2];
-	memset(&insn, 0, sizeof(comedi_insn));
-	insn.insn = INSN_CONFIG;
-	insn.subdev = options.subdevice;
-	insn.chanspec = options.channel;
-	insn.data = data;
-	insn.n = sizeof(data) / sizeof(data[0]);
-	data[0] = INSN_CONFIG_FILTER;
-	data[1] = filter_selection;
 
-	retval = comedi_do_insn(device, &insn);
+	retval = comedi_set_filter(device, options.subdevice, options.channel, filter_selection);
 	if(retval < 0) comedi_perror("comedi_do_insn");
 	return retval;
 }
