@@ -12,7 +12,7 @@
 #include <stdlib.h>
 #include "examples.h"
 
-int read_eeprom(comedi_t *it,unsigned int **eeprom);
+int read_eeprom(comedi_t *it,unsigned int **eeprom, struct parsed_options options);
 void dump_eeprom(unsigned int *eeprom,int len);
 
 comedi_t *device;
@@ -21,16 +21,19 @@ int main(int argc, char *argv[])
 {
 	int len;
 	unsigned int *eeprom;
+	struct parsed_options options;
 
-	parse_options(argc,argv);
+	init_parsed_options(&options);
+	options.subdevice = -1;
+	parse_options(&options, argc, argv);
 
-	device=comedi_open(filename);
+	device = comedi_open(options.filename);
 	if(!device){
-		comedi_perror(filename);
-		exit(0);
+		comedi_perror(options.filename);
+		exit(-1);
 	}
 
-	len=read_eeprom(device,&eeprom);
+	len = read_eeprom(device, &eeprom, options);
 	dump_eeprom(eeprom,len);
 
 	return 0;
@@ -39,33 +42,36 @@ int main(int argc, char *argv[])
 
 
 
-int read_eeprom(comedi_t *it,unsigned int **eeprom)
+int read_eeprom(comedi_t *it, unsigned int **eeprom, struct parsed_options options)
 {
-	int subd;
 	int n,i,ret;
 	lsampl_t data;
 	unsigned int *ptr;
 	lsampl_t maxdata;
 
-	subd=comedi_find_subdevice_by_type(it,COMEDI_SUBD_MEMORY,0);
-	if(subd<0){
-		fprintf(stderr,"No memory subdevice\n");
-		return 0;
+	if(options.subdevice < 0)
+	{
+		options.subdevice = comedi_find_subdevice_by_type(it, COMEDI_SUBD_MEMORY, 0);
+		if(options.subdevice < 0){
+			fprintf(stderr,"No memory subdevice\n");
+			return 0;
+		}
 	}
 
-	n=comedi_get_n_channels(it,subd);
-	maxdata=comedi_get_maxdata(it,subd,0);
+	n = comedi_get_n_channels(it, options.subdevice);
+	maxdata = comedi_get_maxdata(it, options.subdevice, 0);
 
-	if(maxdata!=0xff){
-		fprintf(stderr,"Memory subdevice has strange maxdata, aborting\n");
+	if(maxdata != 0xff){
+		fprintf(stderr,"Demo only supports 8-bit memory subdevice has strange maxdata, aborting\n");
+		exit(-1);
 	}
 
-	ptr=malloc(sizeof(unsigned int)*n);
+	ptr = malloc(sizeof(unsigned int) * n);
 
-	for(i=0;i<n;i++){
-		ret=comedi_data_read(it,subd,i,0,0,&data);
-		ptr[i]=data;
-		if(ret<0){
+	for(i = 0; i < n; i++){
+		ret = comedi_data_read(it, options.subdevice, i, 0, 0, &data);
+		ptr[i] = data;
+		if(ret < 0){
 			comedi_perror("comedi_data_read");
 			return 0;
 		}
