@@ -20,15 +20,24 @@ int aref = AREF_GROUND;	/* more on this later */
 int main(int argc,char *argv[])
 {
 	comedi_t *it;
-	int chan=0;
+	int chan = 0;
 	lsampl_t data;
-	
-	it=comedi_open("/dev/comedi0");
-	
-	comedi_data_read(it,subdev,chan,range,aref,&data);
-	
-	printf("%d\n",data);
-	
+	int retval;
+
+	it = comedi_open("/dev/comedi0");
+	if(it == NULL) {
+		comedi_perror("comedi_open");
+		return 1;
+	}
+
+	retval = comedi_data_read(it, subdev, chan, range, aref, &data);
+	if(retval < 0) {
+		comedi_perror("comedi_data_read");
+		return 1;
+	}
+
+	printf("%d\n", data);
+
 	return 0;
 }
 
