@@ -131,6 +131,16 @@ int comedi_do_insnlist(comedi_t *it,comedi_insnlist *il);
 int comedi_do_insn(comedi_t *it,comedi_insn *insn);
 int comedi_lock(comedi_t *it,unsigned int subdevice);
 int comedi_unlock(comedi_t *it,unsigned int subdevice);
+/*
+ * Changing read and write subdevice is supported for the version of comedi
+ * in the Linux kernel sources since Linux kernel version 3.19.
+ *
+ * The functions to set and get the read and write subdevice are unusual in
+ * that changes are local to the "open file description" for the Comedi
+ * device.
+ */
+int comedi_set_read_subdevice(comedi_t *it,unsigned int subdevice);
+int comedi_set_write_subdevice(comedi_t *it,unsigned int subdevice);
 
 /* physical units */
 double comedi_to_phys(lsampl_t data,comedi_range *rng,lsampl_t maxdata);
@@ -140,11 +150,11 @@ int comedi_sampl_to_phys(double *dest, int dst_stride, sampl_t *src,
 int comedi_sampl_from_phys(sampl_t *dest,int dst_stride,double *src,
 	int src_stride, comedi_range *rng, lsampl_t maxdata, int n);
 
-/* syncronous stuff */
+/* synchronous stuff */
 int comedi_data_read(comedi_t *it,unsigned int subd,unsigned int chan,
 	unsigned int range,unsigned int aref,lsampl_t *SWIG_OUTPUT(data));
 int comedi_data_read_n(comedi_t *it,unsigned int subd,unsigned int chan,
-	unsigned int range,unsigned int aref,lsampl_t *SWIG_OUTPUT(data), unsigned int n);
+	unsigned int range,unsigned int aref,lsampl_t *data, unsigned int n);
 int comedi_data_read_hint(comedi_t *it,unsigned int subd,unsigned int chan,
 	unsigned int range,unsigned int aref);
 int comedi_data_read_delayed(comedi_t *it,unsigned int subd,unsigned int chan,
@@ -191,6 +201,14 @@ int comedi_mark_buffer_read(comedi_t *it, unsigned int subdev,
 	unsigned int bytes);
 int comedi_mark_buffer_written(comedi_t *it, unsigned int subdev,
 	unsigned int bytes);
+int comedi_get_buffer_read_offset(comedi_t *it, unsigned int subdev);
+int comedi_get_buffer_write_offset(comedi_t *it, unsigned int subdev);
+int comedi_get_buffer_read_count(comedi_t *it, unsigned int subdev,
+	unsigned int *SWIG_OUTPUT(read_count));
+int comedi_get_buffer_write_count(comedi_t *it, unsigned int subdev,
+	unsigned int *SWIG_OUTPUT(write_count));
+
+/* Should be moved to _COMEDILIB_DEPRECATED - use comedi_get_buffer_read_offset instead. */
 int comedi_get_buffer_offset(comedi_t *it, unsigned int subdev);
 
 #ifdef _COMEDILIB_DEPRECATED
@@ -286,7 +304,14 @@ lsampl_t comedi_from_physical(double data,
 int comedi_internal_trigger(comedi_t *dev, unsigned subd, unsigned trignum);
 /* INSN_CONFIG wrappers */
 int comedi_arm(comedi_t *device, unsigned subdevice, unsigned source);
+int comedi_arm_channel(comedi_t *device, unsigned subdevice, unsigned channel,
+	unsigned source);
+int comedi_disarm(comedi_t *device, unsigned subdevice);
+int comedi_disarm_channel(comedi_t *device, unsigned subdevice,
+	unsigned channel);
 int comedi_reset(comedi_t *device, unsigned subdevice);
+int comedi_reset_channel(comedi_t *device, unsigned subdevice,
+	unsigned channel);
 int comedi_get_clock_source(comedi_t *device, unsigned subdevice, unsigned channel, unsigned *SWIG_OUTPUT(clock), unsigned *SWIG_OUTPUT(period_ns));
 int comedi_get_gate_source(comedi_t *device, unsigned subdevice, unsigned channel,
 	unsigned gate, unsigned *SWIG_OUTPUT(source));
@@ -299,6 +324,14 @@ int comedi_set_other_source(comedi_t *device, unsigned subdevice, unsigned chann
 	unsigned other, unsigned source);
 int comedi_set_routing(comedi_t *device, unsigned subdevice, unsigned channel, unsigned routing);
 int comedi_get_hardware_buffer_size(comedi_t *device, unsigned subdevice, enum comedi_io_direction direction);
+int comedi_digital_trigger_disable(comedi_t *device, unsigned subdevice,
+	unsigned trigger_id);
+int comedi_digital_trigger_enable_edges(comedi_t *device, unsigned subdevice,
+	unsigned trigger_id, unsigned base_input,
+	unsigned rising_edge_inputs, unsigned falling_edge_inputs);
+int comedi_digital_trigger_enable_levels(comedi_t *device, unsigned subdevice,
+	unsigned trigger_id, unsigned base_input,
+	unsigned high_level_inputs, unsigned low_level_inputs);
 
 #endif
 
