@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_CALIB_YY_COMEDILIB_LIB_CALIB_YACC_H_INCLUDED
 # define YY_CALIB_YY_COMEDILIB_LIB_CALIB_YACC_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,31 +40,30 @@
 extern int calib_yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     T_DRIVER_NAME = 258,
-     T_BOARD_NAME = 259,
-     T_CALIBRATIONS = 260,
-     T_SUBDEVICE = 261,
-     T_CHANNELS = 262,
-     T_RANGES = 263,
-     T_AREFS = 264,
-     T_CALDACS = 265,
-     T_CHANNEL = 266,
-     T_VALUE = 267,
-     T_NUMBER = 268,
-     T_STRING = 269,
-     T_COEFFICIENTS = 270,
-     T_EXPANSION_ORIGIN = 271,
-     T_SOFTCAL_TO_PHYS = 272,
-     T_SOFTCAL_FROM_PHYS = 273,
-     T_ASSIGN = 274,
-     T_FLOAT = 275
-   };
+  enum yytokentype
+  {
+    T_DRIVER_NAME = 258,
+    T_BOARD_NAME = 259,
+    T_CALIBRATIONS = 260,
+    T_SUBDEVICE = 261,
+    T_CHANNELS = 262,
+    T_RANGES = 263,
+    T_AREFS = 264,
+    T_CALDACS = 265,
+    T_CHANNEL = 266,
+    T_VALUE = 267,
+    T_NUMBER = 268,
+    T_STRING = 269,
+    T_COEFFICIENTS = 270,
+    T_EXPANSION_ORIGIN = 271,
+    T_SOFTCAL_TO_PHYS = 272,
+    T_SOFTCAL_FROM_PHYS = 273,
+    T_ASSIGN = 274,
+    T_FLOAT = 275
+  };
 #endif
 /* Tokens.  */
 #define T_DRIVER_NAME 258
@@ -86,40 +85,25 @@ extern int calib_yydebug;
 #define T_ASSIGN 274
 #define T_FLOAT 275
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-/* Line 2053 of yacc.c  */
-#line 347 "../../comedilib/lib/calib_yacc.y"
+#line 347 "../../comedilib/lib/calib_yacc.y" /* yacc.c:1909  */
 
 	int  ival;
 	double dval;
 	char *sval;
 
-
-/* Line 2053 of yacc.c  */
-#line 104 "../../comedilib/lib/calib_yacc.h"
-} YYSTYPE;
+#line 100 "../../comedilib/lib/calib_yacc.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int calib_yyparse (void *YYPARSE_PARAM);
-#else
-int calib_yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
+
 int calib_yyparse (calib_yyparse_private_t *parse_arg);
-#else
-int calib_yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_CALIB_YY_COMEDILIB_LIB_CALIB_YACC_H_INCLUDED  */
