@@ -40,7 +40,7 @@ char *__comedilib_error_strings[]={
 #define n_errors (sizeof(__comedilib_error_strings)/sizeof(void *))
 
 int __comedi_loglevel=1;
-int __comedi_errno=0;
+TLS int __comedi_errno=0;
 
 EXPORT_ALIAS_DEFAULT(_comedi_loglevel,comedi_loglevel,0.7.18);
 int _comedi_loglevel(int loglevel)
@@ -59,7 +59,7 @@ int _comedi_errno(void)
 }
 
 EXPORT_ALIAS_DEFAULT(_comedi_strerror,comedi_strerror,0.7.18);
-char* _comedi_strerror(int errnum)
+const char* _comedi_strerror(int errnum)
 {
 	if(errnum<COMEDI_NOERROR || errnum>=COMEDI_NOERROR+n_errors)
 		return strerror(errnum);
@@ -98,7 +98,7 @@ void internal_error(int err)
 int valid_dev(comedi_t *it)
 {
 	if(!it || it->magic!=COMEDILIB_MAGIC){
-		internal_error(COMEDILIB_BADDEV);
+		internal_error(EBAD_CT);
 		return 0;
 	}
 	
@@ -109,7 +109,7 @@ int valid_subd(comedi_t *it,unsigned int subd)
 {
 	if(!valid_dev(it))return 0;
 	if(subd>=it->n_subdevices){
-		internal_error(COMEDILIB_BADSUBD);
+		internal_error(EINVAL_SUBD);
 		return 0;
 	}
 	
@@ -120,7 +120,7 @@ int valid_chan(comedi_t *it,unsigned int subd,unsigned int chan)
 {
 	if(!valid_subd(it,subd))return 0;
 	if(chan>=it->subdevices[subd].n_chan){
-		internal_error(COMEDILIB_BADCHAN);
+		internal_error(EINVAL_CHAN);
 		return 0;
 	}
 	
