@@ -21,6 +21,8 @@ int test_cmd_fifo_depth_check(void)
 	int len;
 	unsigned int flags = comedi_get_subdevice_flags(device,subdevice);
 
+	/* attempt to make subdevice the current 'read' subdevice */
+	if(flags&SDF_CMD_READ) comedi_set_read_subdevice(device,subdevice);
 	if(!(flags&SDF_CMD) || (comedi_get_read_subdevice(device)!=subdevice)){
 		printf("not applicable\n");
 		return 0;
