@@ -19,8 +19,11 @@ static int do_continuous(int multiplier);
 int test_cmd_continuous(void)
 {
 	int mult;
+	unsigned int flags = comedi_get_subdevice_flags(device,subdevice);
 
-	if(!(comedi_get_subdevice_flags(device,subdevice)&SDF_CMD)){
+	/* attempt to make subdevice the current 'read' subdevice */
+	if(flags&SDF_CMD_READ) comedi_set_read_subdevice(device,subdevice);
+	if(!(flags&SDF_CMD) || (comedi_get_read_subdevice(device)!=subdevice)){
 		printf("not applicable\n");
 		return 0;
 	}
