@@ -13,8 +13,5 @@ extern unsigned int capabilities;
 
 extern int realtime;
 
-extern int comedi_internal_trigger(comedi_t *device,unsigned int subdevice,
-	unsigned int trignum);
-
 #endif
 
